@@ -574,12 +574,19 @@ static int bitvec2freq_list(uint8_t *chan_list, struct bitvec *bv,
 	return bitvec2freq_list(chan_list, bv, bts, false, false);
 }
 
-/* generate a cell channel list as per Section 10.5.2.1b of 04.08 */
+/*! generate a cell channel list as per Section 10.5.2.22 of 04.08
+ *  \param[out] chan_list caller-provided output buffer
+ *  \param[in] bts BTS descriptor used for input data
+ *  \param[in] si5 Are we generating SI5xxx (true) or SI2xxx (false)
+ *  \param[in] bis Are we generating SIXbis (true) or not (false)
+ *  \param[in] ter Are we generating SIXter (true) or not (false)
+ */
 static int generate_bcch_chan_list(uint8_t *chan_list, struct gsm_bts *bts,
 	bool si5, bool bis, bool ter)
 {
 	struct gsm_bts *cur_bts;
 	struct bitvec *bv;
+	int rc;
 
 	if (si5 && bts->neigh_list_manual_mode == NL_MODE_MANUAL_SI5SEP)
 		bv = &bts->si_common.si5_neigh_list;
@@ -600,7 +607,20 @@ static int generate_bcch_chan_list(uint8_t *chan_list, struct gsm_bts *bts,
 	}
 
 	/* then we generate a GSM 04.08 frequency list from the bitvec */
-	return bitvec2freq_list(chan_list, bv, bts, bis, ter);
+	rc = bitvec2freq_list(chan_list, bv, bts, bis, ter);
+	if (rc < 0)
+		return rc;
+
+	/* Set BA-IND depending on whether we're generating SI2 or SI5.
+	 * The point here is to be able to correlate whether a given MS
+	 * measurement report was using the neighbor cells advertised in
+	 * SI2 or in SI5, as those two could very well be different */
+	if (si5)
+		chan_list[0] |= 0x10;
+	else
+		chan_list[0] &= ~0x10;
+
+	return rc;
 }
 
 static int list_arfcn(uint8_t *chan_list, uint8_t mask, char *text)
@@ -1079,15 +1099,10 @@ static struct gsm48_si13_info si13_default = {
 	},
 	.bcch_change_mark	= 1,
 	.si_change_field	= 0,
-	.pbcch_present		= 0,
-	{
-		.no_pbcch = {
-			.rac		= 0,	/* needs to be patched */
-			.spgc_ccch_sup 	= 0,
-			.net_ctrl_ord	= 0,
-			.prio_acc_thr	= 6,
-		},
-	},
+	.rac		= 0,	/* needs to be patched */
+	.spgc_ccch_sup 	= 0,
+	.net_ctrl_ord	= 0,
+	.prio_acc_thr	= 6,
 };
 
 static int generate_si13(enum osmo_sysinfo_type t, struct gsm_bts *bts)
@@ -1102,8 +1117,8 @@ static int generate_si13(enum osmo_sysinfo_type t, struct gsm_bts *bts)
 	si13->header.skip_indicator = 0;
 	si13->header.system_information = GSM48_MT_RR_SYSINFO_13;
 
-	si13_default.no_pbcch.rac = bts->gprs.rac;
-	si13_default.no_pbcch.net_ctrl_ord = bts->gprs.net_ctrl_ord;
+	si13_default.rac = bts->gprs.rac;
+	si13_default.net_ctrl_ord = bts->gprs.net_ctrl_ord;
 
 	si13_default.cell_opts.ctrl_ack_type_use_block =
 		bts->gprs.ctrl_ack_type_use_block;
